Changelog
=========
Current Release (0.2)
------------------
* kloudi: Manages automation of AWS accounts and services.

0.2
~~~~~~~
* feature: initial public release, S3 provisioning, name change to kloudi


0.1
~~~~~~~
* feature: initial public release, EC2 provisioning
